@@ -1,12 +1,7 @@
-from typing import Optional
-
-import httpx
-
-
 class HTTPError(Exception):
     """Base HTTP error with status code and message."""
 
-    def __init__(self, status_code: int, message: str, response: Optional[httpx.Response] = None) -> None:
+    def __init__(self, status_code: int, message: str, response: object | None = None) -> None:
         super().__init__(f"{status_code}: {message}")
         self.status_code = status_code
         self.message = message
