@@ -388,7 +388,7 @@ class EndpointResponseHandlerGenerator:
         # All code paths should be covered by the match statement above
         writer.write_line("# All paths above should return or raise - this should never execute")
         context.add_import("typing", "NoReturn")
-        writer.write_line("assert False, 'Unexpected code path'  # pragma: no cover")
+        writer.write_line("raise RuntimeError('Unexpected code path')  # pragma: no cover")
         writer.write_line("")  # Add a blank line for readability
 
     def _write_strategy_based_return(
