@@ -495,7 +495,7 @@ class TestSchemaParser(unittest.TestCase):
         invalid_node: Any = "not a mapping"
 
         # Act & Assert
-        with self.assertRaises(AssertionError) as context:
+        with self.assertRaises(TypeError) as context:
             _parse_schema(schema_name, invalid_node, self.context, allow_self_reference=False)
 
         self.assertIn("must be a Mapping", str(context.exception))
@@ -517,7 +517,8 @@ class TestSchemaParser(unittest.TestCase):
         # Assert
         self.assertIsNotNone(schema_ir)
         self.assertEqual(schema_ir.name, schema_name)
-        self.assertIsNone(schema_ir.type)
+        # Empty schemas default to 'object' type per OpenAPI spec
+        self.assertEqual(schema_ir.type, "object")
         self.assertEqual(schema_ir.properties, {})
         self.assertEqual(schema_ir.required, [])
 
